@@ -2,16 +2,16 @@ import unittest
 from typing import Optional, Union, Dict, Any, Tuple
 from uuid import uuid4
 
-from StructNoSQL import DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineCachingTable, FieldSetter, \
+from StructNoSQL import DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiCachingTable, FieldSetter, \
     FieldGetter, FieldRemover
-from StructNoSQL.middlewares.inoft_vocal_engine.inoft_vocal_engine_basic_table import InoftVocalEngineBasicTable
+from StructNoSQL.clients_middlewares.external_dynamodb_api.external_dynamodb_api_basic_table import ExternalDynamoDBApiBasicTable
 from tests.components.playground_table_clients import TEST_ACCOUNT_ID
 
 
 def test_get_field(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     simple_field_random_text_value: str = f"simpleField_randomTextValue_{uuid4()}"
@@ -45,8 +45,8 @@ def test_get_field(
 
 def test_get_field_multi_selectors(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     container_field_one_random_text_value: str = f"container_fieldOne_randomTextValue_{uuid4()}"
@@ -96,8 +96,8 @@ def test_get_field_multi_selectors(
 
 def test_get_multiple_fields(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     container_field_one_random_text_value: str = f"container_fieldOne_randomTextValue_{uuid4()}"
@@ -154,8 +154,8 @@ def test_get_multiple_fields(
 
 def test_remove_field(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     def generate_update_simple_field_text_value() -> str:
@@ -193,8 +193,8 @@ def test_remove_field(
 
 def test_remove_field_multi_selectors(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     def generate_update_container_fields_text_values() -> Tuple[str, str]:
@@ -248,8 +248,8 @@ def test_remove_field_multi_selectors(
 
 def test_remove_multiple_fields(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     def generate_update_container_fields_text_values() -> Tuple[str, str]:
@@ -309,8 +309,8 @@ def test_remove_multiple_fields(
 
 def test_grouped_remove_multiple_fields(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     def generate_update_container_fields_text_values() -> Tuple[str, str]:
@@ -370,8 +370,8 @@ def test_grouped_remove_multiple_fields(
 
 def test_update_field_return_old(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     simple_field_random_text_value: str = f"simpleField_randomTextValue_{uuid4()}"
@@ -408,8 +408,8 @@ def test_update_field_return_old(
 
 def test_update_multiple_fields_return_old(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     container_field_one_random_text_value: str = f"container_fieldOne_randomTextValue_{uuid4()}"
@@ -464,8 +464,8 @@ def test_update_multiple_fields_return_old(
 
 def test_query_field(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     simple_field_random_text_value: str = f"simpleField_randomTextValue_{uuid4()}"
@@ -477,9 +477,10 @@ def test_query_field(
         self.assertTrue(first_table.commit_operations())
         first_table.clear_cached_data()
 
-    second_table_retrieved_simple_field_without_data_validation: Optional[Any] = second_table.query_field(
+    second_table_retrieved_simple_field_without_data_validation, query_metadata = second_table.query_field(
         key_value=TEST_ACCOUNT_ID, field_path='simpleField', data_validation=False
     )
+    second_table_retrieved_simple_field_without_data_validation: Optional[Any]
     self.assertEqual({TEST_ACCOUNT_ID: (
         simple_field_random_text_value if is_caching is not True else
         {'value': simple_field_random_text_value, 'fromCache': False}
@@ -488,9 +489,10 @@ def test_query_field(
     if is_caching is True:
         second_table.clear_cached_data()
 
-    second_table_retrieved_simple_field_with_data_validation: Optional[int] = second_table.query_field(
+    second_table_retrieved_simple_field_with_data_validation, query_metadata = second_table.query_field(
         key_value=TEST_ACCOUNT_ID, field_path='simpleField', data_validation=True
     )
+    second_table_retrieved_simple_field_with_data_validation: Optional[int]
     self.assertEqual({TEST_ACCOUNT_ID: (
         None if is_caching is not True else
         {'value': None, 'fromCache': False}
@@ -499,8 +501,8 @@ def test_query_field(
 
 def test_query_field_multi_selectors(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     container_field_one_random_text_value: str = f"container_fieldOne_randomTextValue_{uuid4()}"
@@ -516,9 +518,10 @@ def test_query_field_multi_selectors(
         self.assertTrue(first_table.commit_operations())
         first_table.clear_cached_data()
 
-    second_table_retrieved_container_fields_without_data_validation: Dict[str, Optional[Any]] = second_table.query_field(
+    second_table_retrieved_container_fields_without_data_validation, query_metadata = second_table.query_field(
         key_value=TEST_ACCOUNT_ID, field_path='container.(nestedFieldOne, nestedFieldTwo)', data_validation=False
     )
+    second_table_retrieved_container_fields_without_data_validation: Dict[str, Optional[Any]]
     self.assertEqual({TEST_ACCOUNT_ID: {
         'nestedFieldOne': (
             container_field_one_random_text_value if is_caching is not True else
@@ -533,9 +536,10 @@ def test_query_field_multi_selectors(
     if is_caching is True:
         second_table.clear_cached_data()
 
-    second_table_retrieved_container_fields_with_data_validation: Dict[str, Optional[int]] = second_table.query_field(
+    second_table_retrieved_container_fields_with_data_validation, query_metadata = second_table.query_field(
         key_value=TEST_ACCOUNT_ID, field_path='container.(nestedFieldOne, nestedFieldTwo)', data_validation=True
     )
+    second_table_retrieved_container_fields_with_data_validation: Dict[str, Optional[int]]
     self.assertEqual({TEST_ACCOUNT_ID: {
         'nestedFieldOne': (
             None if is_caching is not True else
@@ -550,8 +554,8 @@ def test_query_field_multi_selectors(
 
 def test_query_multiple_fields(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     container_field_one_random_text_value: str = f"container_fieldOne_randomTextValue_{uuid4()}"
@@ -568,12 +572,13 @@ def test_query_multiple_fields(
         self.assertTrue(first_table.commit_operations())
         first_table.clear_cached_data()
 
-    second_table_retrieved_container_fields_without_data_validation: Dict[str, Optional[Any]] = second_table.query_multiple_fields(
+    second_table_retrieved_container_fields_without_data_validation, query_metadata = second_table.query_multiple_fields(
         key_value=TEST_ACCOUNT_ID, data_validation=False, getters={
             'one': FieldGetter(field_path='container.nestedFieldOne'),
             'two': FieldGetter(field_path='container.nestedFieldTwo'),
         }
     )
+    second_table_retrieved_container_fields_without_data_validation: Dict[str, Optional[Any]]
     self.assertEqual({TEST_ACCOUNT_ID: {
         'one': (
             container_field_one_random_text_value if is_caching is not True else
@@ -588,12 +593,13 @@ def test_query_multiple_fields(
     if is_caching is True:
         second_table.clear_cached_data()
 
-    second_table_retrieved_container_fields_with_data_validation: Dict[str, Optional[int]] = second_table.query_multiple_fields(
+    second_table_retrieved_container_fields_with_data_validation, query_metadata = second_table.query_multiple_fields(
         key_value=TEST_ACCOUNT_ID, data_validation=True, getters={
             'one': FieldGetter(field_path='container.nestedFieldOne'),
             'two': FieldGetter(field_path='container.nestedFieldTwo'),
         }
     )
+    second_table_retrieved_container_fields_with_data_validation: Dict[str, Optional[int]]
     self.assertEqual({TEST_ACCOUNT_ID: {
         'one': (
             None if is_caching is not True else
@@ -608,8 +614,8 @@ def test_query_multiple_fields(
 
 def test_remove_record(
         self: unittest.TestCase,
-        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
-        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, InoftVocalEngineBasicTable, InoftVocalEngineCachingTable],
+        first_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
+        second_table: Union[DynamoDBBasicTable, DynamoDBCachingTable, ExternalDynamoDBApiBasicTable, ExternalDynamoDBApiCachingTable],
         is_caching: bool, primary_key_name: str
 ):
     random_record_id: str = f"recordId_{uuid4()}"
